# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/exchange-info/api.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from galts_trade_api.transport.protos.exchange_info import entities_pb2 as protos_dot_exchange__info_dot_entities__pb2
from galts_trade_api.transport.protos import common_pb2 as protos_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/exchange-info/api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x1eprotos/exchange-info/api.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a#protos/exchange-info/entities.proto\x1a\x13protos/common.proto\"\x10\n\x02Id\x12\n\n\x02id\x18\x01 \x01(\x05\"0\n\x0b\x45ntityKinds\x12!\n\x0c\x65ntity_kinds\x18\x01 \x03(\x0e\x32\x0b.EntityKind\"\x96\x03\n\x08\x45ntities\x12%\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x15.Entities.AssetsEntry\x12\'\n\x07symbols\x18\x02 \x03(\x0b\x32\x16.Entities.SymbolsEntry\x12\'\n\x07markets\x18\x03 \x03(\x0b\x32\x16.Entities.MarketsEntry\x12+\n\texchanges\x18\x04 \x03(\x0b\x32\x18.Entities.ExchangesEntry\x1a\x35\n\x0b\x41ssetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x15\n\x05value\x18\x02 \x01(\x0b\x32\x06.Asset:\x02\x38\x01\x1a\x37\n\x0cSymbolsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x16\n\x05value\x18\x02 \x01(\x0b\x32\x07.Symbol:\x02\x38\x01\x1a\x37\n\x0cMarketsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x16\n\x05value\x18\x02 \x01(\x0b\x32\x07.Market:\x02\x38\x01\x1a;\n\x0e\x45xchangesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x18\n\x05value\x18\x02 \x01(\x0b\x32\t.Exchange:\x02\x38\x01\":\n\nAddAssetIn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x11\n\tprecision\x18\x03 \x01(\x05\"<\n\x0b\x41\x64\x64SymbolIn\x12\x15\n\rbase_asset_id\x18\x01 \x01(\x05\x12\x16\n\x0equote_asset_id\x18\x02 \x01(\x05\"a\n\x0b\x41\x64\x64MarketIn\x12\x12\n\ncustom_tag\x18\x01 \x01(\t\x12\x11\n\tsymbol_id\x18\x02 \x01(\x05\x12\x13\n\x0b\x65xchange_id\x18\x03 \x01(\x05\x12\x16\n\x0etrade_endpoint\x18\x04 \x01(\t\"*\n\rAddExchangeIn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"V\n\x1bSubscribeToEntitiesChangeIn\x12\x14\n\x0csession_hash\x18\x01 \x01(\t\x12!\n\x0c\x65ntity_kinds\x18\x02 \x03(\x0e\x32\x0b.EntityKind\"\xbb\x01\n\x1cSubscribeToEntitiesChangeOut\x12\x0f\n\x07\x63ounter\x18\x01 \x01(\x03\x12\x14\n\x0c\x63ounter_prev\x18\x02 \x01(\x03\x12\x17\n\x05\x61sset\x18\x03 \x01(\x0b\x32\x06.AssetH\x00\x12\x19\n\x06symbol\x18\x04 \x01(\x0b\x32\x07.SymbolH\x00\x12\x19\n\x06market\x18\x05 \x01(\x0b\x32\x07.MarketH\x00\x12\x1d\n\x08\x65xchange\x18\x06 \x01(\x0b\x32\t.ExchangeH\x00\x42\x06\n\x04kind*=\n\nEntityKind\x12\t\n\x05\x41SSET\x10\x00\x12\n\n\x06SYMBOL\x10\x01\x12\n\n\x06MARKET\x10\x02\x12\x0c\n\x08\x45XCHANGE\x10\x03\x32\xfb\x05\n\x0f\x45xchangeInfoApi\x12\x34\n\x0cStartSession\x12\x16.google.protobuf.Empty\x1a\x0c.SessionHash\x12*\n\rFinishSession\x12\x0c.SessionHash\x1a\x0b.BoolResult\x12Z\n\x19SubscribeToEntitiesChange\x12\x1c.SubscribeToEntitiesChangeIn\x1a\x1d.SubscribeToEntitiesChangeOut0\x01\x12&\n\x0bGetEntities\x12\x0c.EntityKinds\x1a\t.Entities\x12\x1c\n\x08\x41\x64\x64\x41sset\x12\x0b.AddAssetIn\x1a\x03.Id\x12\x17\n\x08GetAsset\x12\x03.Id\x1a\x06.Asset\x12*\n\x0b\x44\x65leteAsset\x12\x03.Id\x1a\x16.google.protobuf.Empty\x12\x1e\n\tAddSymbol\x12\x0c.AddSymbolIn\x1a\x03.Id\x12\x19\n\tGetSymbol\x12\x03.Id\x1a\x07.Symbol\x12+\n\x0c\x44\x65leteSymbol\x12\x03.Id\x1a\x16.google.protobuf.Empty\x12\x1e\n\tAddMarket\x12\x0c.AddMarketIn\x1a\x03.Id\x12\x19\n\tGetMarket\x12\x03.Id\x1a\x07.Market\x12+\n\x0c\x44\x65leteMarket\x12\x03.Id\x1a\x16.google.protobuf.Empty\x12\"\n\x0b\x41\x64\x64\x45xchange\x12\x0e.AddExchangeIn\x1a\x03.Id\x12\x1d\n\x0bGetExchange\x12\x03.Id\x1a\t.Exchange\x12-\n\x0e\x44\x65leteExchange\x12\x03.Id\x1a\x16.google.protobuf.Empty\x12.\n\x0f\x44isableExchange\x12\x03.Id\x1a\x16.google.protobuf.Empty\x12-\n\x0e\x45nableExchange\x12\x03.Id\x1a\x16.google.protobuf.Emptyb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,protos_dot_exchange__info_dot_entities__pb2.DESCRIPTOR,protos_dot_common__pb2.DESCRIPTOR,])

_ENTITYKIND = _descriptor.EnumDescriptor(
  name='EntityKind',
  full_name='EntityKind',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ASSET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYMBOL', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MARKET', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXCHANGE', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1141,
  serialized_end=1202,
)
_sym_db.RegisterEnumDescriptor(_ENTITYKIND)

EntityKind = enum_type_wrapper.EnumTypeWrapper(_ENTITYKIND)
ASSET = 0
SYMBOL = 1
MARKET = 2
EXCHANGE = 3



_ID = _descriptor.Descriptor(
  name='Id',
  full_name='Id',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Id.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=137,
)


_ENTITYKINDS = _descriptor.Descriptor(
  name='EntityKinds',
  full_name='EntityKinds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entity_kinds', full_name='EntityKinds.entity_kinds', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=187,
)


_ENTITIES_ASSETSENTRY = _descriptor.Descriptor(
  name='AssetsEntry',
  full_name='Entities.AssetsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Entities.AssetsEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Entities.AssetsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=421,
)

_ENTITIES_SYMBOLSENTRY = _descriptor.Descriptor(
  name='SymbolsEntry',
  full_name='Entities.SymbolsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Entities.SymbolsEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Entities.SymbolsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=478,
)

_ENTITIES_MARKETSENTRY = _descriptor.Descriptor(
  name='MarketsEntry',
  full_name='Entities.MarketsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Entities.MarketsEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Entities.MarketsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=480,
  serialized_end=535,
)

_ENTITIES_EXCHANGESENTRY = _descriptor.Descriptor(
  name='ExchangesEntry',
  full_name='Entities.ExchangesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Entities.ExchangesEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='Entities.ExchangesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=596,
)

_ENTITIES = _descriptor.Descriptor(
  name='Entities',
  full_name='Entities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='assets', full_name='Entities.assets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbols', full_name='Entities.symbols', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='markets', full_name='Entities.markets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchanges', full_name='Entities.exchanges', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ENTITIES_ASSETSENTRY, _ENTITIES_SYMBOLSENTRY, _ENTITIES_MARKETSENTRY, _ENTITIES_EXCHANGESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=596,
)


_ADDASSETIN = _descriptor.Descriptor(
  name='AddAssetIn',
  full_name='AddAssetIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='AddAssetIn.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='AddAssetIn.tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precision', full_name='AddAssetIn.precision', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=598,
  serialized_end=656,
)


_ADDSYMBOLIN = _descriptor.Descriptor(
  name='AddSymbolIn',
  full_name='AddSymbolIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_asset_id', full_name='AddSymbolIn.base_asset_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quote_asset_id', full_name='AddSymbolIn.quote_asset_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=658,
  serialized_end=718,
)


_ADDMARKETIN = _descriptor.Descriptor(
  name='AddMarketIn',
  full_name='AddMarketIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_tag', full_name='AddMarketIn.custom_tag', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol_id', full_name='AddMarketIn.symbol_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='AddMarketIn.exchange_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trade_endpoint', full_name='AddMarketIn.trade_endpoint', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=720,
  serialized_end=817,
)


_ADDEXCHANGEIN = _descriptor.Descriptor(
  name='AddExchangeIn',
  full_name='AddExchangeIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='AddExchangeIn.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag', full_name='AddExchangeIn.tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=861,
)


_SUBSCRIBETOENTITIESCHANGEIN = _descriptor.Descriptor(
  name='SubscribeToEntitiesChangeIn',
  full_name='SubscribeToEntitiesChangeIn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_hash', full_name='SubscribeToEntitiesChangeIn.session_hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity_kinds', full_name='SubscribeToEntitiesChangeIn.entity_kinds', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=863,
  serialized_end=949,
)


_SUBSCRIBETOENTITIESCHANGEOUT = _descriptor.Descriptor(
  name='SubscribeToEntitiesChangeOut',
  full_name='SubscribeToEntitiesChangeOut',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='counter', full_name='SubscribeToEntitiesChangeOut.counter', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counter_prev', full_name='SubscribeToEntitiesChangeOut.counter_prev', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset', full_name='SubscribeToEntitiesChangeOut.asset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='SubscribeToEntitiesChangeOut.symbol', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='market', full_name='SubscribeToEntitiesChangeOut.market', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='SubscribeToEntitiesChangeOut.exchange', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='SubscribeToEntitiesChangeOut.kind',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=952,
  serialized_end=1139,
)

_ENTITYKINDS.fields_by_name['entity_kinds'].enum_type = _ENTITYKIND
_ENTITIES_ASSETSENTRY.fields_by_name['value'].message_type = protos_dot_exchange__info_dot_entities__pb2._ASSET
_ENTITIES_ASSETSENTRY.containing_type = _ENTITIES
_ENTITIES_SYMBOLSENTRY.fields_by_name['value'].message_type = protos_dot_exchange__info_dot_entities__pb2._SYMBOL
_ENTITIES_SYMBOLSENTRY.containing_type = _ENTITIES
_ENTITIES_MARKETSENTRY.fields_by_name['value'].message_type = protos_dot_exchange__info_dot_entities__pb2._MARKET
_ENTITIES_MARKETSENTRY.containing_type = _ENTITIES
_ENTITIES_EXCHANGESENTRY.fields_by_name['value'].message_type = protos_dot_exchange__info_dot_entities__pb2._EXCHANGE
_ENTITIES_EXCHANGESENTRY.containing_type = _ENTITIES
_ENTITIES.fields_by_name['assets'].message_type = _ENTITIES_ASSETSENTRY
_ENTITIES.fields_by_name['symbols'].message_type = _ENTITIES_SYMBOLSENTRY
_ENTITIES.fields_by_name['markets'].message_type = _ENTITIES_MARKETSENTRY
_ENTITIES.fields_by_name['exchanges'].message_type = _ENTITIES_EXCHANGESENTRY
_SUBSCRIBETOENTITIESCHANGEIN.fields_by_name['entity_kinds'].enum_type = _ENTITYKIND
_SUBSCRIBETOENTITIESCHANGEOUT.fields_by_name['asset'].message_type = protos_dot_exchange__info_dot_entities__pb2._ASSET
_SUBSCRIBETOENTITIESCHANGEOUT.fields_by_name['symbol'].message_type = protos_dot_exchange__info_dot_entities__pb2._SYMBOL
_SUBSCRIBETOENTITIESCHANGEOUT.fields_by_name['market'].message_type = protos_dot_exchange__info_dot_entities__pb2._MARKET
_SUBSCRIBETOENTITIESCHANGEOUT.fields_by_name['exchange'].message_type = protos_dot_exchange__info_dot_entities__pb2._EXCHANGE
_SUBSCRIBETOENTITIESCHANGEOUT.oneofs_by_name['kind'].fields.append(
  _SUBSCRIBETOENTITIESCHANGEOUT.fields_by_name['asset'])
_SUBSCRIBETOENTITIESCHANGEOUT.fields_by_name['asset'].containing_oneof = _SUBSCRIBETOENTITIESCHANGEOUT.oneofs_by_name['kind']
_SUBSCRIBETOENTITIESCHANGEOUT.oneofs_by_name['kind'].fields.append(
  _SUBSCRIBETOENTITIESCHANGEOUT.fields_by_name['symbol'])
_SUBSCRIBETOENTITIESCHANGEOUT.fields_by_name['symbol'].containing_oneof = _SUBSCRIBETOENTITIESCHANGEOUT.oneofs_by_name['kind']
_SUBSCRIBETOENTITIESCHANGEOUT.oneofs_by_name['kind'].fields.append(
  _SUBSCRIBETOENTITIESCHANGEOUT.fields_by_name['market'])
_SUBSCRIBETOENTITIESCHANGEOUT.fields_by_name['market'].containing_oneof = _SUBSCRIBETOENTITIESCHANGEOUT.oneofs_by_name['kind']
_SUBSCRIBETOENTITIESCHANGEOUT.oneofs_by_name['kind'].fields.append(
  _SUBSCRIBETOENTITIESCHANGEOUT.fields_by_name['exchange'])
_SUBSCRIBETOENTITIESCHANGEOUT.fields_by_name['exchange'].containing_oneof = _SUBSCRIBETOENTITIESCHANGEOUT.oneofs_by_name['kind']
DESCRIPTOR.message_types_by_name['Id'] = _ID
DESCRIPTOR.message_types_by_name['EntityKinds'] = _ENTITYKINDS
DESCRIPTOR.message_types_by_name['Entities'] = _ENTITIES
DESCRIPTOR.message_types_by_name['AddAssetIn'] = _ADDASSETIN
DESCRIPTOR.message_types_by_name['AddSymbolIn'] = _ADDSYMBOLIN
DESCRIPTOR.message_types_by_name['AddMarketIn'] = _ADDMARKETIN
DESCRIPTOR.message_types_by_name['AddExchangeIn'] = _ADDEXCHANGEIN
DESCRIPTOR.message_types_by_name['SubscribeToEntitiesChangeIn'] = _SUBSCRIBETOENTITIESCHANGEIN
DESCRIPTOR.message_types_by_name['SubscribeToEntitiesChangeOut'] = _SUBSCRIBETOENTITIESCHANGEOUT
DESCRIPTOR.enum_types_by_name['EntityKind'] = _ENTITYKIND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Id = _reflection.GeneratedProtocolMessageType('Id', (_message.Message,), {
  'DESCRIPTOR' : _ID,
  '__module__' : 'protos.exchange_info.api_pb2'
  # @@protoc_insertion_point(class_scope:Id)
  })
_sym_db.RegisterMessage(Id)

EntityKinds = _reflection.GeneratedProtocolMessageType('EntityKinds', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYKINDS,
  '__module__' : 'protos.exchange_info.api_pb2'
  # @@protoc_insertion_point(class_scope:EntityKinds)
  })
_sym_db.RegisterMessage(EntityKinds)

Entities = _reflection.GeneratedProtocolMessageType('Entities', (_message.Message,), {

  'AssetsEntry' : _reflection.GeneratedProtocolMessageType('AssetsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ENTITIES_ASSETSENTRY,
    '__module__' : 'protos.exchange_info.api_pb2'
    # @@protoc_insertion_point(class_scope:Entities.AssetsEntry)
    })
  ,

  'SymbolsEntry' : _reflection.GeneratedProtocolMessageType('SymbolsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ENTITIES_SYMBOLSENTRY,
    '__module__' : 'protos.exchange_info.api_pb2'
    # @@protoc_insertion_point(class_scope:Entities.SymbolsEntry)
    })
  ,

  'MarketsEntry' : _reflection.GeneratedProtocolMessageType('MarketsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ENTITIES_MARKETSENTRY,
    '__module__' : 'protos.exchange_info.api_pb2'
    # @@protoc_insertion_point(class_scope:Entities.MarketsEntry)
    })
  ,

  'ExchangesEntry' : _reflection.GeneratedProtocolMessageType('ExchangesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ENTITIES_EXCHANGESENTRY,
    '__module__' : 'protos.exchange_info.api_pb2'
    # @@protoc_insertion_point(class_scope:Entities.ExchangesEntry)
    })
  ,
  'DESCRIPTOR' : _ENTITIES,
  '__module__' : 'protos.exchange_info.api_pb2'
  # @@protoc_insertion_point(class_scope:Entities)
  })
_sym_db.RegisterMessage(Entities)
_sym_db.RegisterMessage(Entities.AssetsEntry)
_sym_db.RegisterMessage(Entities.SymbolsEntry)
_sym_db.RegisterMessage(Entities.MarketsEntry)
_sym_db.RegisterMessage(Entities.ExchangesEntry)

AddAssetIn = _reflection.GeneratedProtocolMessageType('AddAssetIn', (_message.Message,), {
  'DESCRIPTOR' : _ADDASSETIN,
  '__module__' : 'protos.exchange_info.api_pb2'
  # @@protoc_insertion_point(class_scope:AddAssetIn)
  })
_sym_db.RegisterMessage(AddAssetIn)

AddSymbolIn = _reflection.GeneratedProtocolMessageType('AddSymbolIn', (_message.Message,), {
  'DESCRIPTOR' : _ADDSYMBOLIN,
  '__module__' : 'protos.exchange_info.api_pb2'
  # @@protoc_insertion_point(class_scope:AddSymbolIn)
  })
_sym_db.RegisterMessage(AddSymbolIn)

AddMarketIn = _reflection.GeneratedProtocolMessageType('AddMarketIn', (_message.Message,), {
  'DESCRIPTOR' : _ADDMARKETIN,
  '__module__' : 'protos.exchange_info.api_pb2'
  # @@protoc_insertion_point(class_scope:AddMarketIn)
  })
_sym_db.RegisterMessage(AddMarketIn)

AddExchangeIn = _reflection.GeneratedProtocolMessageType('AddExchangeIn', (_message.Message,), {
  'DESCRIPTOR' : _ADDEXCHANGEIN,
  '__module__' : 'protos.exchange_info.api_pb2'
  # @@protoc_insertion_point(class_scope:AddExchangeIn)
  })
_sym_db.RegisterMessage(AddExchangeIn)

SubscribeToEntitiesChangeIn = _reflection.GeneratedProtocolMessageType('SubscribeToEntitiesChangeIn', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBETOENTITIESCHANGEIN,
  '__module__' : 'protos.exchange_info.api_pb2'
  # @@protoc_insertion_point(class_scope:SubscribeToEntitiesChangeIn)
  })
_sym_db.RegisterMessage(SubscribeToEntitiesChangeIn)

SubscribeToEntitiesChangeOut = _reflection.GeneratedProtocolMessageType('SubscribeToEntitiesChangeOut', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBETOENTITIESCHANGEOUT,
  '__module__' : 'protos.exchange_info.api_pb2'
  # @@protoc_insertion_point(class_scope:SubscribeToEntitiesChangeOut)
  })
_sym_db.RegisterMessage(SubscribeToEntitiesChangeOut)


_ENTITIES_ASSETSENTRY._options = None
_ENTITIES_SYMBOLSENTRY._options = None
_ENTITIES_MARKETSENTRY._options = None
_ENTITIES_EXCHANGESENTRY._options = None

_EXCHANGEINFOAPI = _descriptor.ServiceDescriptor(
  name='ExchangeInfoApi',
  full_name='ExchangeInfoApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1205,
  serialized_end=1968,
  methods=[
  _descriptor.MethodDescriptor(
    name='StartSession',
    full_name='ExchangeInfoApi.StartSession',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=protos_dot_common__pb2._SESSIONHASH,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FinishSession',
    full_name='ExchangeInfoApi.FinishSession',
    index=1,
    containing_service=None,
    input_type=protos_dot_common__pb2._SESSIONHASH,
    output_type=protos_dot_common__pb2._BOOLRESULT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeToEntitiesChange',
    full_name='ExchangeInfoApi.SubscribeToEntitiesChange',
    index=2,
    containing_service=None,
    input_type=_SUBSCRIBETOENTITIESCHANGEIN,
    output_type=_SUBSCRIBETOENTITIESCHANGEOUT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetEntities',
    full_name='ExchangeInfoApi.GetEntities',
    index=3,
    containing_service=None,
    input_type=_ENTITYKINDS,
    output_type=_ENTITIES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddAsset',
    full_name='ExchangeInfoApi.AddAsset',
    index=4,
    containing_service=None,
    input_type=_ADDASSETIN,
    output_type=_ID,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAsset',
    full_name='ExchangeInfoApi.GetAsset',
    index=5,
    containing_service=None,
    input_type=_ID,
    output_type=protos_dot_exchange__info_dot_entities__pb2._ASSET,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAsset',
    full_name='ExchangeInfoApi.DeleteAsset',
    index=6,
    containing_service=None,
    input_type=_ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddSymbol',
    full_name='ExchangeInfoApi.AddSymbol',
    index=7,
    containing_service=None,
    input_type=_ADDSYMBOLIN,
    output_type=_ID,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSymbol',
    full_name='ExchangeInfoApi.GetSymbol',
    index=8,
    containing_service=None,
    input_type=_ID,
    output_type=protos_dot_exchange__info_dot_entities__pb2._SYMBOL,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSymbol',
    full_name='ExchangeInfoApi.DeleteSymbol',
    index=9,
    containing_service=None,
    input_type=_ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddMarket',
    full_name='ExchangeInfoApi.AddMarket',
    index=10,
    containing_service=None,
    input_type=_ADDMARKETIN,
    output_type=_ID,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMarket',
    full_name='ExchangeInfoApi.GetMarket',
    index=11,
    containing_service=None,
    input_type=_ID,
    output_type=protos_dot_exchange__info_dot_entities__pb2._MARKET,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMarket',
    full_name='ExchangeInfoApi.DeleteMarket',
    index=12,
    containing_service=None,
    input_type=_ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddExchange',
    full_name='ExchangeInfoApi.AddExchange',
    index=13,
    containing_service=None,
    input_type=_ADDEXCHANGEIN,
    output_type=_ID,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetExchange',
    full_name='ExchangeInfoApi.GetExchange',
    index=14,
    containing_service=None,
    input_type=_ID,
    output_type=protos_dot_exchange__info_dot_entities__pb2._EXCHANGE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteExchange',
    full_name='ExchangeInfoApi.DeleteExchange',
    index=15,
    containing_service=None,
    input_type=_ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DisableExchange',
    full_name='ExchangeInfoApi.DisableExchange',
    index=16,
    containing_service=None,
    input_type=_ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EnableExchange',
    full_name='ExchangeInfoApi.EnableExchange',
    index=17,
    containing_service=None,
    input_type=_ID,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXCHANGEINFOAPI)

DESCRIPTOR.services_by_name['ExchangeInfoApi'] = _EXCHANGEINFOAPI

# @@protoc_insertion_point(module_scope)
